################################################
## this module was created during the PTS2023 ##
## to test a specific behaviour on            ##
## PAUSE/MetaCPAN. It is not supposed to be   ##
## used and may be deleted at any time.       ##
################################################
package Acme::Testing::BadPackages::WithoutRootdir;
use strict;
use warnings;

our $VERSION = '0.1';

1;
